Imported from archive.
[mudpy.git] / mudpy.py
index 3650f89..c989f0f 100644 (file)
--- a/mudpy.py
+++ b/mudpy.py
@@ -651,8 +651,8 @@ class User:
                        # find and replace macros in the output
                        output = replace_macros(self, output)
 
-                       # wrap the text at 80 characters
-                       output = wrap_ansi_text(output, 80)
+                       # wrap the text at 79 characters
+                       output = wrap_ansi_text(output, 79)
 
                        # tack the terminator back on
                        if terminate: output += self.terminator